Class: Clogs::SlotDecoration

Inherits:
Drawable
  • Object
show all
Defined in:
lib/clogs/drawables/shapes.rb

Overview

Background and Border cover the slot that contains them rather than occupying a place in its layout.

Direct Known Subclasses

Background, Border

Instance Attribute Summary

Attributes inherited from Drawable

#abs_x, #abs_y, #children, #height, #parent, #shoes_linkable_id, #styles, #width, #x, #y

Instance Method Summary collapse

Methods inherited from Drawable

#add_child, #app, #clickable?, #contains?, #destroy_self, #draw, #each_peer, #focus_gained, #focus_lost, #focusable?, for_shoes_class, #hidden?, #initialize, #margin, #needs_layout!, #notify, #on_click, #on_key, #on_mouse_move, #on_release, #paint, #positioned?, #properties_changed, #redraw!, #remove_child, #requested_height, #requested_width, #set_parent, #style

Constructor Details

This class inherits a constructor from Clogs::Drawable

Instance Method Details

#measure(_available_width) ⇒ Object



248
# File 'lib/clogs/drawables/shapes.rb', line 248

def measure(_available_width); end

#measure_for_slot(width, height) ⇒ Object



243
244
245
246
# File 'lib/clogs/drawables/shapes.rb', line 243

def measure_for_slot(width, height)
  @width = width
  @height = height
end